@@ -47,7 +47,4 @@ class Sentence(TextElement):
         return [self]
     
     def get_words(self) -> List[Word]:
-        return self.components
-
-    def __str__(self):
-        return self.text
+        return self.components
\ No newline at end of file
